==> haskell-clientsession-0.9.1.2-30-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-clientsession.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: clientsession
version: 0.9.1.2
id: clientsession-0.9.1.2-4r06vQGSNMm2jkzUY5TdKv
key: clientsession-0.9.1.2-4r06vQGSNMm2jkzUY5TdKv
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: stable
homepage: http://github.com/yesodweb/clientsession/tree/master
synopsis: Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.
category: Web
author: Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Web.ClientSession
hidden-modules: System.LookupEnv
abi: fc1f62597afc6fa97cd3753d508f3655
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/clientsession-0.9.1.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/clientsession-0.9.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/clientsession-0.9.1.2
hs-libraries: HSclientsession-0.9.1.2-4r06vQGSNMm2jkzUY5TdKv
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    cereal-0.5.4.0-HHG4trmDAey7tG5Rc3nyML directory-1.3.0.2
    tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2
    crypto-api-0.13.2-1dBjbzCEPqW6HZX5e7BC7M
    skein-1.0.9.4-G6fZK2Zo4zlmOGjA7OSvP
    base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be
    entropy-0.3.8-459fr1KgYZzBPF08mWgtQU
    cprng-aes-0.6.1-LEJdsrxCe3DDPv0vnj85C7
    cipher-aes-0.2.11-2AcZkDlMC1P6HBBcDalMAM
    crypto-random-0.0.9-1uxAwoiZWoF7pXQs22tMDK
    setenv-0.1.1.3-4FEJPUU51wbJmlhCSZScDf
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             cereal-0.5.4.0-HHG4trmDAey7tG5Rc3nyML=ed459ea038cbdb253abe2c011f65c556
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
             crypto-api-0.13.2-1dBjbzCEPqW6HZX5e7BC7M=dc378fcb3f233843676419c1ea364719
             skein-1.0.9.4-G6fZK2Zo4zlmOGjA7OSvP=ba78ab953b74befc0a692f7c43f33d8c
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fd5db0dc9688093c1ac2c3223371478e
             entropy-0.3.8-459fr1KgYZzBPF08mWgtQU=48b904d4ac32d9c7078ceefe10d1973a
             cprng-aes-0.6.1-LEJdsrxCe3DDPv0vnj85C7=17848334effdd5c0fd983db5221e42bd
             cipher-aes-0.2.11-2AcZkDlMC1P6HBBcDalMAM=230281f6557b6ddbde4bf7ed493d7136
             crypto-random-0.0.9-1uxAwoiZWoF7pXQs22tMDK=d3932cd4b816c8a3706c733b15ea64ee
             setenv-0.1.1.3-4FEJPUU51wbJmlhCSZScDf=47f2e6fa4c7735b4d7b72a0a7181676d
haddock-interfaces: /usr/share/doc/haskell-clientsession/html/clientsession.haddock
haddock-html: /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-clientsession-0.9.1.2-31-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-clientsession.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: clientsession
version: 0.9.1.2
id: clientsession-0.9.1.2-9KYwqTt3AeI3sLVE8YbthM
key: clientsession-0.9.1.2-9KYwqTt3AeI3sLVE8YbthM
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: stable
homepage: http://github.com/yesodweb/clientsession/tree/master
synopsis: Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.
category: Web
author: Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Web.ClientSession
hidden-modules: System.LookupEnv
abi: bb0898ec5c75dc038e202bccda876728
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/clientsession-0.9.1.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/clientsession-0.9.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/clientsession-0.9.1.2
hs-libraries: HSclientsession-0.9.1.2-9KYwqTt3AeI3sLVE8YbthM
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    cereal-0.5.4.0-HHG4trmDAey7tG5Rc3nyML directory-1.3.0.2
    tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2
    crypto-api-0.13.2-1dBjbzCEPqW6HZX5e7BC7M
    skein-1.0.9.4-G6fZK2Zo4zlmOGjA7OSvP
    base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be
    entropy-0.3.8-459fr1KgYZzBPF08mWgtQU
    cprng-aes-0.6.1-3VprLDbsYvX6MRF3GKWbvy
    cipher-aes-0.2.11-9Rx88MLXAh5Auj7NIcSrrH
    crypto-random-0.0.9-J75SZnAN3rZF55BWVYjD5q
    setenv-0.1.1.3-4FEJPUU51wbJmlhCSZScDf
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             cereal-0.5.4.0-HHG4trmDAey7tG5Rc3nyML=ed459ea038cbdb253abe2c011f65c556
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
             crypto-api-0.13.2-1dBjbzCEPqW6HZX5e7BC7M=dc378fcb3f233843676419c1ea364719
             skein-1.0.9.4-G6fZK2Zo4zlmOGjA7OSvP=ba78ab953b74befc0a692f7c43f33d8c
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fd5db0dc9688093c1ac2c3223371478e
             entropy-0.3.8-459fr1KgYZzBPF08mWgtQU=48b904d4ac32d9c7078ceefe10d1973a
             cprng-aes-0.6.1-3VprLDbsYvX6MRF3GKWbvy=56d878353ef23a69593de4fc37d84456
             cipher-aes-0.2.11-9Rx88MLXAh5Auj7NIcSrrH=b68ba43e387b8f331a2da882c38e4993
             crypto-random-0.0.9-J75SZnAN3rZF55BWVYjD5q=777a113b860d634611fe57e199d73233
             setenv-0.1.1.3-4FEJPUU51wbJmlhCSZScDf=47f2e6fa4c7735b4d7b72a0a7181676d
haddock-interfaces: /usr/share/doc/haskell-clientsession/html/clientsession.haddock
haddock-html: /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
